@@ -45,7 +45,7 @@ import net.sourceforge.jtds.ssl.Ssl;
  * @author Brian Heineman
  * @author Mike Hutchinson
  * @author Alin Sinpalean
- * @version $Id: Driver.java,v 1.70 2007/08/02 22:35:27 bheineman Exp $
+ * @version $Id: Driver.java,v 1.70.2.4 2009/12/30 11:19:40 ickzon Exp $
  */
 public class Driver implements java.sql.Driver {
     /** URL prefix used by the driver (i.e <code>jdbc:jtds:</code>). */
@@ -55,7 +55,7 @@ public class Driver implements java.sql.Driver {
     /** Driver minor version. */
     static final int MINOR_VERSION = 2;
     /** Driver version miscellanea (e.g "-rc2", ".1" or <code>null</code>). */
-    static final String MISC_VERSION = ".2";
+    static final String MISC_VERSION = ".5";
     /** Set if the JDBC specification to implement is 3.0 or greater. */
     public static final boolean JDBC3 =
             "1.4".compareTo(System.getProperty("java.specification.version")) <= 0;
@@ -104,6 +104,8 @@ public class Driver implements java.sql.Driver {
     public static final String SERVERNAME    = "prop.servername";
     public static final String SERVERTYPE    = "prop.servertype";
     public static final String SOTIMEOUT     = "prop.sotimeout";
+    public static final String SOKEEPALIVE   = "prop.sokeepalive";
+    public static final String PROCESSID     = "prop.processid";
     public static final String SSL           = "prop.ssl";
     public static final String TCPNODELAY    = "prop.tcpnodelay";
     public static final String TDS           = "prop.tds";
