@@ -42,7 +42,7 @@ import net.sourceforge.jtds.util.Logger;
  *
  * @author Alin Sinplean
  * @since  jTDS 0.3
- * @version $Id: JtdsDataSource.java,v 1.42 2007/08/05 17:50:39 bheineman Exp $
+ * @version $Id: JtdsDataSource.java,v 1.42.2.4 2009/12/30 08:45:34 ickzon Exp $
  */
 public class JtdsDataSource
         implements DataSource, ConnectionPoolDataSource, XADataSource, Referenceable, Serializable {
@@ -77,6 +77,8 @@ public class JtdsDataSource
     protected String xaEmulation;
     protected String logFile;
     protected String socketTimeout;
+    protected String socketKeepAlive;
+    protected String processId;
     protected String ssl;
     protected String batchSize;
     protected String bufferDir;
@@ -213,6 +215,8 @@ public class JtdsDataSource
         ref.add(new StringRefAddr(Messages.get(Driver.PASSWORD), password));
         ref.add(new StringRefAddr(Messages.get(Driver.LOGINTIMEOUT), loginTimeout));
         ref.add(new StringRefAddr(Messages.get(Driver.SOTIMEOUT), socketTimeout));
+        ref.add(new StringRefAddr(Messages.get(Driver.SOKEEPALIVE), socketKeepAlive));
+        ref.add(new StringRefAddr(Messages.get(Driver.PROCESSID), processId));
         ref.add(new StringRefAddr(Messages.get(Driver.LOBBUFFER), lobBuffer));
         ref.add(new StringRefAddr(Messages.get(Driver.MAXSTATEMENTS), maxStatements));
         ref.add(new StringRefAddr(Messages.get(Driver.APPNAME), appName));
@@ -291,6 +295,13 @@ public class JtdsDataSource
         this.socketTimeout = String.valueOf(socketTimeout);
     }
 
+    public void setSocketKeepAlive(boolean socketKeepAlive) throws SQLException {
+        this.socketKeepAlive = String.valueOf(socketKeepAlive);
+    }
+    public void setProcessId(String processId) throws SQLException {
+        this.processId = String.valueOf(processId);
+    }
+    
     public int getSocketTimeout() throws SQLException {
         if (socketTimeout == null) {
             return 0;
@@ -298,6 +309,14 @@ public class JtdsDataSource
         return Integer.parseInt(socketTimeout);
     }
 
+    public boolean getSocketKeepAlive() throws SQLException {
+        return Boolean.valueOf(socketKeepAlive).booleanValue();
+    }
+
+    public String getProcessId() throws SQLException {
+        return processId;
+    }
+
     public void setDatabaseName(String databaseName) {
         this.databaseName = databaseName;
     }
@@ -690,6 +709,12 @@ public class JtdsDataSource
         if (socketTimeout != null) {
             props.setProperty(Messages.get(Driver.SOTIMEOUT), socketTimeout);
         }
+        if (socketKeepAlive != null) {
+            props.setProperty(Messages.get(Driver.SOKEEPALIVE), socketKeepAlive);
+        }
+        if (processId != null) {
+            props.setProperty(Messages.get(Driver.PROCESSID), processId);
+        }
         if (lobBuffer != null) {
             props.setProperty(Messages.get(Driver.LOBBUFFER), lobBuffer);
         }
@@ -736,4 +761,23 @@ public class JtdsDataSource
             props.setProperty(Messages.get(Driver.USEJCIFS), useJCIFS);
         }
     }
-}
+
+    /////// JDBC4 demarcation, do NOT put any JDBC3 code below this line ///////
+
+    /* (non-Javadoc)
+     * @see java.sql.Wrapper#isWrapperFor(java.lang.Class)
+     */
+    public boolean isWrapperFor(Class arg0) throws SQLException {
+        // TODO Auto-generated method stub
+        throw new AbstractMethodError();
+    }
+
+    /* (non-Javadoc)
+     * @see java.sql.Wrapper#unwrap(java.lang.Class)
+     */
+    public Object unwrap(Class arg0) throws SQLException {
+        // TODO Auto-generated method stub
+        throw new AbstractMethodError();
+    }
+
+}
\ No newline at end of file
